<!DOCTYPE TS><TS>
<context>
    <name></name>
    <message>
        <source>command not found</source>
        <translation>команди не знайдено</translation>
    </message>
</context>
<context>
    <name>@default</name>
    <message>
        <source>Operation successfully completed.</source>
        <translation>Операцію успішно завершено.</translation>
    </message>
    <message>
        <source>An error has occurs during the operation.</source>
        <translation>Під час виконання операції виникла помилка.</translation>
    </message>
    <message>
        <source>An error has happened during the ped_disk_new call.</source>
        <translation>Виникла помилка під час виклику ped_disk_new.</translation>
    </message>
    <message>
        <source>An error has happened during the ped_disk_get_partition call.</source>
        <translation>Виникла помилка під час виклику ped_disk_get_partition.</translation>
    </message>
    <message>
        <source>An error has happened during ped_partition_new call.</source>
        <translation>Виникла помилка під час виклику ped_partition_call.</translation>
    </message>
    <message>
        <source>An error has happened during ped_disk_add_partition call.</source>
        <translation>Виникла помилка під час виклику ped_disk_add_partition.</translation>
    </message>
    <message>
        <source>An error has happened during ped_partition_set_system call.</source>
        <translation>Виникла помилка під час виклику ped_partition_set_system.</translation>
    </message>
    <message>
        <source>An error has happened during ped_partition_set_flag call.</source>
        <translation>Виникла помилка під час виклику ped_partition_set_flag.</translation>
    </message>
    <message>
        <source>An error has happened during ped_disk_delete_partition call.</source>
        <translation>Виникла помилка під час виклику ped_disk_delete_partition.</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <source>A program that create NTFS partitions.</source>
        <translation>Програма, яка створює розділ NTFS.</translation>
    </message>
    <message>
        <source>A program that resize NTFS partitions.</source>
        <translation>Програма, яка змінює розмір розділу NTFS.</translation>
    </message>
    <message>
        <source>A program that create EXT3 partitions.</source>
        <translation>Програма, яка створює розділ EXT3.</translation>
    </message>
    <message>
        <source>A program that create JFS partitions.</source>
        <translation>Програма, яка створю розділ JFS.</translation>
    </message>
    <message>
        <source>A program that create XFS partitions.</source>
        <translation>Програма, яка створює розділ XFS.</translation>
    </message>
    <message>
        <source>Cannot read /proc/partitions, QTParted cannot be used!.
Please use a kernel with /proc/partitions support.</source>
        <translation type="obsolete">Неможливо прочитати /proc/partitions, не можливо використати QTParted!
Будьласка, використовуйте ядро з підтримкою /proc/partitions.</translation>
    </message>
    <message>
        <source>Cannot get parted version.</source>
        <translation>Неможливо визначити версію parted.</translation>
    </message>
    <message>
        <source>Parted is too old:
- installed parted version: %1.%2.%3
- required parted version: %4.%5.%6 (or better)

Parted homepage: http://www.gnu.org/software/parted/</source>
        <translation>Занадто устаріла версія parted:
- установлена версія parted: %1.%2.%3
- необхідна версія parted: %4.%5.%6 (или старше)

Домашня сторінка parted: http://www.gnu.org/software/parted/</translation>
    </message>
    <message>
        <source>Cannot umount partition device: %1.Please do it by hand first to commit the changes!</source>
        <translation>Не можу відмонтувати розділ пристрою: %1. Будьласка, здійсніть це самі для застосування змін!</translation>
    </message>
    <message>
        <source>Utility for mount a filesystem.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Utility for umount a filesystem.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Utility for grow a xfs filesystem.</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>QP_ActionList</name>
    <message>
        <source>Getting info about partition %1.</source>
        <translation>Збирання інформації про розділ %1.</translation>
    </message>
    <message>
        <source>Creating partition.</source>
        <translation>Стврорення розділу.</translation>
    </message>
    <message>
        <source>Preparation for removing a partition.</source>
        <translation>Підготовка до видалення розділу.</translation>
    </message>
    <message>
        <source>Removing a partition.</source>
        <translation>Видалення розділу.</translation>
    </message>
    <message>
        <source>Preparation for resizing a partition.</source>
        <translation>Підготовка до зміни розміру розділу.</translation>
    </message>
    <message>
        <source>Resizing a partition.</source>
        <translation>Зміна розділу розміру.</translation>
    </message>
    <message>
        <source>Preparation for activating a partition.</source>
        <translation>Підготовка до активації розділу.</translation>
    </message>
    <message>
        <source>Activating a partition.</source>
        <translation>Активація розділу.</translation>
    </message>
    <message>
        <source>Preparation for formatting a partition.</source>
        <translation>Підготовка до форматування розділу.</translation>
    </message>
    <message>
        <source>Formatting a partition.</source>
        <translation>Форматування розділу.</translation>
    </message>
    <message>
        <source>Rescan of the disk.</source>
        <translation>Повторне сканування диску.</translation>
    </message>
    <message>
        <source>Preparation for moving a partition.</source>
        <translation>Підготовка до пересування розділу.</translation>
    </message>
    <message>
        <source>Moving a partition.</source>
        <translation>Пересування розділу.</translation>
    </message>
    <message>
        <source>All operations completed.</source>
        <translation>Усі операції завершені.</translation>
    </message>
    <message>
        <source>Critical error during ped_disk_new!</source>
        <translation>Критична помилка під час ped_disk_new!</translation>
    </message>
    <message>
        <source>Critical error during ped_disk_duplicate!</source>
        <translation>Критична помилка під час ped_disk_duplicate!</translation>
    </message>
    <message>
        <source>Preparation for hiding a partition.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Hiding a partition.</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>QP_DriveList</name>
    <message>
        <source>No device found. Maybe you&apos;re not using root user?</source>
        <translation>Пристрій не знайдено. Можливо во не є користувачем root?</translation>
    </message>
    <message>
        <source>Device</source>
        <translation>Пристрій</translation>
    </message>
    <message>
        <source>Disks</source>
        <translation>Диски</translation>
    </message>
</context>
<context>
    <name>QP_FSExt3</name>
    <message>
        <source>Writing superblocks and filesystem.</source>
        <translation>Зипис суперблоку та файлової системи.</translation>
    </message>
    <message>
        <source>Writing inode tables.</source>
        <translation>Зипис таблиці i-вузлів.</translation>
    </message>
    <message>
        <source>There was a problem with mkfs.ext3.</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>QP_FSJfs</name>
    <message>
        <source>Cannot enlarge a partition if the disk device is busy</source>
        <translation type="unfinished">Не можу розширити розділ, якщо пристрій зайнятий</translation>
    </message>
</context>
<context>
    <name>QP_FSNtfs</name>
    <message>
        <source>Cannot enlarge a partition if the disk device is busy</source>
        <translation type="unfinished">Не можу розширити розділ, якщо пристрій зайнятий</translation>
    </message>
    <message>
        <source>Resizing in progress.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Syncing device.</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>QP_FSReiserFS</name>
    <message>
        <source>No label</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>QP_FSXfs</name>
    <message>
        <source>There was a problem with mkfs.xfs.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Cannot enlarge a partition if the disk device is busy</source>
        <translation type="unfinished">Не можу розширити розділ, якщо пристрій зайнятий</translation>
    </message>
    <message>
        <source>Error during xfs_grow.</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>QP_LibParted</name>
    <message>
        <source>The partition is mounted.</source>
        <translation>Розділ подмонтований.</translation>
    </message>
    <message>
        <source>Can&apos;t move extended partitions.</source>
        <translation>Не можу пересувати розширені розділи.</translation>
    </message>
    <message>
        <source>Can&apos;t move a partition onto itself. Try using resize, perhaps?</source>
        <translation>Не можу перемістити розділ у самого себе. Спробувати змінити розмір?</translation>
    </message>
    <message>
        <source>An error happen during ped_geometry_init call.</source>
        <translation>Виникла помилка під час виклику ped_geometry_init.</translation>
    </message>
    <message>
        <source>An error happen during ped_disk_set_partition_geom call.</source>
        <translation>Виникла помилка під час виклику ped_disk_set_partition_geom.</translation>
    </message>
    <message>
        <source>An error happen during ped_file_system_open call.</source>
        <translation>Виникла помилка під час виклику ped_file_system_open.</translation>
    </message>
    <message>
        <source>An error happen during ped_file_system_resize call.</source>
        <translation>Виникла помилка під час виклику ped_file_system_resize.</translation>
    </message>
    <message>
        <source>Scanning all disk partitions.</source>
        <translation>Сканування усіх розділів диску.</translation>
    </message>
    <message>
        <source>Partition %s is being used.</source>
        <translation>Розділ %s у даний момент використовується.</translation>
    </message>
    <message>
        <source>Cannot change the active status on this partition</source>
        <translation>Не можливо змінити статус активного розділу</translation>
    </message>
    <message>
        <source>A bug was found in QTParted during set_system, please report it!</source>
        <translation>В QTParted була знайдена помилка під час set_system, повідомте про це, будьласка!</translation>
    </message>
    <message>
        <source>A bug was found in QTParted during ped_file_system_type_get, please report it!</source>
        <translation>В QTParted була знайдена помилка під час ped_file_system_type_get, повідомте про це, будьласка!</translation>
    </message>
    <message>
        <source>This is a virtual partition. You cannot alter it: use undo instead.</source>
        <translation>Це - віртуальний розділ. Ви не можете його змінити: використайте відміну.</translation>
    </message>
    <message>
        <source>A bug was found in QTParted during &quot;resize&quot; scan, please report it!</source>
        <translation>В QTParted була знайдена помилка під час &quot;resize&quot;, повідомте про це, будьласка!</translation>
    </message>
    <message>
        <source>A bug was found in QTParted during &quot;mkfs&quot; scan, please report it!</source>
        <translation>В QTParted була знайдена помилка під час сканування &quot;mkfs&quot;, повідомте про це, будьласка!</translation>
    </message>
    <message>
        <source>Error committing device.
This can happen when a device is mounted in the disk.
Try to unmount all partitions on this disk.
Please read the FAQ for this kind of error!</source>
        <translation>Помилка роботи з пристроєм.
Це могло статися у випадку, коли розділ диску є підмонтованим.
Спробуйте відмонтувати усі розділи диску.
Будьласка, прочитайте FAQ для таких помилок!</translation>
    </message>
    <message>
        <source>A bug was found in QTParted during &quot;move&quot; scan, please report it!</source>
        <translation>В QTParted була знайдена помилка під час сканування &quot;move&quot;, повідомте про це, будьласка!</translation>
    </message>
    <message>
        <source>Cannot change the hidden status on this partition</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>QP_MainWindow</name>
    <message>
        <source>&amp;Quit</source>
        <translation>В&amp;ихід</translation>
    </message>
    <message>
        <source>Quit</source>
        <translation>Вихід</translation>
    </message>
    <message>
        <source>Quit from the application</source>
        <translation>Вихід із программи</translation>
    </message>
    <message>
        <source>&amp;Property</source>
        <translation>&amp;Властивості</translation>
    </message>
    <message>
        <source>Property</source>
        <translation>Властивості</translation>
    </message>
    <message>
        <source>Property of the selected partition</source>
        <translation>Властивості виділеного розділу</translation>
    </message>
    <message>
        <source>&amp;Create</source>
        <translation>&amp;Створити</translation>
    </message>
    <message>
        <source>Create a new partition</source>
        <translation>Створити новий розділ</translation>
    </message>
    <message>
        <source>&amp;Resize</source>
        <translation>&amp;Змінити розмір</translation>
    </message>
    <message>
        <source>Resize</source>
        <translation>Змінити розмір</translation>
    </message>
    <message>
        <source>Resize a partition</source>
        <translation>Змінити розмір розділу</translation>
    </message>
    <message>
        <source>&amp;Move</source>
        <translation>&amp;Пересунути</translation>
    </message>
    <message>
        <source>Move</source>
        <translation>Пересунути</translation>
    </message>
    <message>
        <source>Move a partition</source>
        <translation>Пересунути розділ</translation>
    </message>
    <message>
        <source>&amp;Delete</source>
        <translation>Ви&amp;далити</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Видалити</translation>
    </message>
    <message>
        <source>Delete a new partition</source>
        <translation>Видалити новий розділ</translation>
    </message>
    <message>
        <source>&amp;File</source>
        <translation>&amp;Файл</translation>
    </message>
    <message>
        <source>&amp;Operations</source>
        <translation>&amp;Операції</translation>
    </message>
    <message>
        <source>this is a %1 partition
it start at: %2 and end at: %3
it can grow left: %4 and right: %5
the filesystem is: %6</source>
        <translation type="unfinished">Це %1 розділ.
він починається з %2 та закінчується %3
його можно збільшити вліво на %4 та право на %5
файлова система: %6</translation>
    </message>
    <message>
        <source>Enter &lt;b&gt;What&apos;s This&lt;/b&gt; modeIt enables the user to ask for help about widgets on the screen.</source>
        <translation>Для отримання справки про віджети, що на екрані, ви можете скористуватися пунктом меню &lt;b&gt;What&apos;s This&lt;/b&gt;.</translation>
    </message>
    <message>
        <source>Create</source>
        <translation>Створити</translation>
    </message>
    <message>
        <source>What&apos;s &amp;This</source>
        <translation>Що ц&amp;е</translation>
    </message>
    <message>
        <source>What&apos;s This</source>
        <translation>Що це</translation>
    </message>
    <message>
        <source>About QT</source>
        <translation>Про QT</translation>
    </message>
    <message>
        <source>Information about QT</source>
        <translation>Інформація про QT</translation>
    </message>
    <message>
        <source>&amp;Help</source>
        <translation>До&amp;помога</translation>
    </message>
    <message>
        <source>About &amp;QTParted</source>
        <translation>Про &amp;QTParted</translation>
    </message>
    <message>
        <source>About QTParted</source>
        <translation>Про QTParted</translation>
    </message>
    <message>
        <source>Information about QTParted</source>
        <translation>Інформація про QTParted</translation>
    </message>
    <message>
        <source>About Q&amp;T</source>
        <translation>Про Q&amp;T</translation>
    </message>
    <message>
        <source>About</source>
        <translation>Про</translation>
    </message>
    <message>
        <source>An internal error happened during partition scan.
This means that you cannot resize or move this partition.</source>
        <translation>Під час сканування розділу виникла внутрішня помилка.
Це означає, що ви не можете змінити розмір цього розділу, а також пересувати його.</translation>
    </message>
    <message>
        <source>Getting devices</source>
        <translation>Пошук пристроїв</translation>
    </message>
    <message>
        <source>load user settings</source>
        <translation>загрузка установок користувачів</translation>
    </message>
    <message>
        <source>Ready</source>
        <translation>Готово</translation>
    </message>
    <message>
        <source>&amp;Undo</source>
        <translation>&amp;Відмінити</translation>
    </message>
    <message>
        <source>Undo</source>
        <translation>Відмінити</translation>
    </message>
    <message>
        <source>Undo last operation</source>
        <translation>Відміна останньої операції</translation>
    </message>
    <message>
        <source>&amp;Commit</source>
        <translation>&amp;Застосувати</translation>
    </message>
    <message>
        <source>Commit</source>
        <translation>Застосувати</translation>
    </message>
    <message>
        <source>Commit all operations</source>
        <translation>Застосувати усі операції</translation>
    </message>
    <message>
        <source>&amp;Configuration...</source>
        <translation>&amp;Конфігурація...</translation>
    </message>
    <message>
        <source>Configuration of QTParted</source>
        <translation>Конфігурація QTParted</translation>
    </message>
    <message>
        <source>Open the configuration dialog</source>
        <translation>Відкрити конфігураційний діалог</translation>
    </message>
    <message>
        <source>Set Active...</source>
        <translation>Зробити активним...</translation>
    </message>
    <message>
        <source>&amp;Disks</source>
        <translation>&amp;Диски</translation>
    </message>
    <message>
        <source>&amp;Options</source>
        <translation>&amp;Опції</translation>
    </message>
    <message>
        <source>This is a virtual partition. You cannot alter it: use undo instead.</source>
        <translation>Це - віртуальний розділ. Ви не можете його змінити: використайте відміну.</translation>
    </message>
    <message>
        <source>primary</source>
        <translation>основний</translation>
    </message>
    <message>
        <source>logical</source>
        <translation>логічний</translation>
    </message>
    <message>
        <source>extended</source>
        <translation>розширений</translation>
    </message>
    <message>
        <source>(No Active on Drive)</source>
        <translation>(Не має активних розділів ни диску)</translation>
    </message>
    <message>
        <source>Currently active partition: %1
Change active partition to: %2

Are you sure you want to change the active partition?</source>
        <translation>На даний момент активним розділом є %1
Зробити активним розділ %2

Ви упевнені, що хочете змінити активний розділ?</translation>
    </message>
    <message>
        <source>&amp;Format</source>
        <translation>&amp;Форматувати</translation>
    </message>
    <message>
        <source>Format</source>
        <translation>Форматувати</translation>
    </message>
    <message>
        <source>Format a new partition</source>
        <translation>Форматувати новий розділ</translation>
    </message>
    <message>
        <source>&amp;Device property</source>
        <translation>Властивості &amp;пристрою</translation>
    </message>
    <message>
        <source>&amp;Make a new Partition Table</source>
        <translation>&amp;Створити нову таблицю розділів</translation>
    </message>
    <message>
        <source>This will make the partition table</source>
        <translation>Це створить таблицю розділів</translation>
    </message>
    <message>
        <source>You&apos;re going to loose all partition data! Are you sure? :)</source>
        <translation>Ви загубите усю інформацію розділу! Ви упевнені? :)</translation>
    </message>
    <message>
        <source>detected</source>
        <translation>знайдено</translation>
    </message>
    <message>
        <source>none</source>
        <translation>ні</translation>
    </message>
    <message>
        <source>You&apos;re going to make a new partition table. Are you sure?
All data will be lost!</source>
        <translation>Ви створите нову таблицю розділів. Ви упевнені?
Уся інформація буде загублена!</translation>
    </message>
    <message>
        <source>It was not possible to make a new partition table.</source>
        <translation>Не можливо створити нову таблицю розділів.</translation>
    </message>
    <message>
        <source>Device status: readonly.</source>
        <translation>Статус пристрою: лише для читання.</translation>
    </message>
    <message>
        <source>Device status: busy.</source>
        <translation>Статус пристрою: зайнято.</translation>
    </message>
    <message>
        <source>Device status: available.</source>
        <translation>Статус пристрою: вільне.</translation>
    </message>
    <message>
        <source>You&apos;re commiting all changes. Warning, you can lost data!
Make sure also that you&apos;re not commiting a busy device...
In other word PLEASE UMOUNT ALL PARTITIONS before commiting changes!</source>
        <translation>Ви застосовуєте усі зміни. Ви можете втратити інформацію!
Упевніться в тому, що ви не будете використовувати зайнятий пристрій...
Іншими словами, БУДЬЛАСКА, ВІДМОНТУЙТЕ УСІ РОЗДІЛИ, перед тим як застосувати зміни!</translation>
    </message>
    <message>
        <source>&amp;Device</source>
        <translation>&amp;Пристрій</translation>
    </message>
    <message>
        <source>See the property of this disk device</source>
        <translation>Дивіться властивості даного пристрою</translation>
    </message>
    <message>
        <source>Some information about the disk device</source>
        <translation>Стисла інформація про диск</translation>
    </message>
    <message>
        <source>Hide</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>QP_NavView</name>
    <message>
        <source>The following drives have been detected:</source>
        <translation>Були знайдені слідуючі накопичувачі:</translation>
    </message>
    <message>
        <source>Drive Info</source>
        <translation>Інформація про диск</translation>
    </message>
    <message>
        <source>Device:</source>
        <translation>Пристрій:</translation>
    </message>
    <message>
        <source>Model:</source>
        <translation>Модель:</translation>
    </message>
    <message>
        <source>Capacity (Mb):</source>
        <translation>Місткість (MB):</translation>
    </message>
    <message>
        <source>Length sectors:</source>
        <translation>Довжина секторів:</translation>
    </message>
    <message>
        <source>No Drive Selected</source>
        <translation>Не Обрано Пристрій</translation>
    </message>
    <message>
        <source>Status: </source>
        <translation>Статус:</translation>
    </message>
    <message>
        <source>readonly.</source>
        <translation>лише для читання.</translation>
    </message>
    <message>
        <source>busy.</source>
        <translation>зайнято.</translation>
    </message>
    <message>
        <source>available.</source>
        <translation>вільно.</translation>
    </message>
</context>
<context>
    <name>QP_PartInfo</name>
    <message>
        <source>This is a virtual partition. You cannot alter it: use undo instead.</source>
        <translation>Це - віртуальний розділ. Ви не можете його змінити: використайте відміну.</translation>
    </message>
    <message>
        <source>Bug during mkfs! Cannot format virtual partitions!</source>
        <translation>Помилка mkfs! Не можу форматувати віртуальний розділ!</translation>
    </message>
    <message>
        <source>Cannot enlarge a partition if the disk device is busy</source>
        <translation type="obsolete">Не можу розширити розділ, якщо пристрій зайнятий</translation>
    </message>
</context>
<context>
    <name>QP_RealListView</name>
    <message>
        <source>Number</source>
        <translation>Номер</translation>
    </message>
    <message>
        <source>Partition</source>
        <translation>Розділ</translation>
    </message>
    <message>
        <source>Type</source>
        <translation>Тип</translation>
    </message>
    <message>
        <source>Start</source>
        <translation>Початок</translation>
    </message>
    <message>
        <source>End</source>
        <translation>Кінець</translation>
    </message>
    <message>
        <source>Status</source>
        <translation>Статус</translation>
    </message>
    <message>
        <source>Size</source>
        <translation>Розмір</translation>
    </message>
    <message>
        <source>Used space</source>
        <translation>Заповнено</translation>
    </message>
    <message>
        <source>Active</source>
        <translation>Активний</translation>
    </message>
    <message>
        <source>N/A</source>
        <translation>Не визначено</translation>
    </message>
    <message>
        <source>Empty</source>
        <translation>Пустий</translation>
    </message>
    <message>
        <source>Partition table</source>
        <translation>Таблиця розділів</translation>
    </message>
    <message>
        <source>Label</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Hidden</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>QP_UIConfig</name>
    <message>
        <source>&amp;OK</source>
        <translation>&amp;Так</translation>
    </message>
    <message>
        <source>&amp;Cancel</source>
        <translation>&amp;Ні</translation>
    </message>
    <message>
        <source>Configuration</source>
        <translation>Конфігурація</translation>
    </message>
    <message>
        <source>QTParted &amp;layout</source>
        <translation>QTParted &amp;формат</translation>
    </message>
    <message>
        <source>Chart and ListBox</source>
        <translation>Діаграмма та список</translation>
    </message>
    <message>
        <source>Only Chart</source>
        <translation>Лише діаграмма</translation>
    </message>
    <message>
        <source>Only ListBox</source>
        <translation>Лише список</translation>
    </message>
    <message>
        <source>&amp;External Tools</source>
        <translation>&amp;Зовнішні засоби</translation>
    </message>
    <message>
        <source>&amp;Full executable path</source>
        <translation>&amp;Повний шлях</translation>
    </message>
</context>
<context>
    <name>QP_UICreate</name>
    <message>
        <source>Create partition</source>
        <translation>Створити розділ</translation>
    </message>
    <message>
        <source>&amp;Size:</source>
        <translation>&amp;Розмір:</translation>
    </message>
    <message>
        <source>Create &amp;as:</source>
        <translation>Створити &amp;як:</translation>
    </message>
    <message>
        <source>&amp;Label:</source>
        <translation>&amp;Мітка:</translation>
    </message>
    <message>
        <source>&amp;Partition Type:</source>
        <translation>Тип &amp;розділу:</translation>
    </message>
    <message>
        <source>Position</source>
        <translation>Позиція</translation>
    </message>
    <message>
        <source>&amp;Beginning of unallocated space</source>
        <translation>На &amp;початку пустого розділу</translation>
    </message>
    <message>
        <source>&amp;End of unallocated space</source>
        <translation>У &amp;кінці пустого розділу</translation>
    </message>
    <message>
        <source>Pe&amp;rcent of unallocated space:</source>
        <translation>&amp;Процентів від пустого розділу:</translation>
    </message>
    <message>
        <source>&amp;OK</source>
        <translation>&amp;Так</translation>
    </message>
    <message>
        <source>&amp;Cancel</source>
        <translation>&amp;Ні</translation>
    </message>
</context>
<context>
    <name>QP_UIDeviceProperty</name>
    <message>
        <source>Device property</source>
        <translation>Властивості пристрою</translation>
    </message>
    <message>
        <source>Device short name</source>
        <translation>Коротке ім&apos;я пристрою</translation>
    </message>
    <message>
        <source>Device long name</source>
        <translation>Довге ім&apos;я пристрою</translation>
    </message>
    <message>
        <source>&amp;Close</source>
        <translation>&amp;Закрити</translation>
    </message>
</context>
<context>
    <name>QP_UIFormat</name>
    <message>
        <source>Format partition</source>
        <translation>Форматувати розділ</translation>
    </message>
    <message>
        <source>&amp;OK</source>
        <translation>&amp;Так</translation>
    </message>
    <message>
        <source>&amp;Cancel</source>
        <translation>&amp;Ні</translation>
    </message>
    <message>
        <source>&amp;Partition Type:</source>
        <translation>Тип &amp;розділу:</translation>
    </message>
    <message>
        <source>&amp;Label:</source>
        <translation>&amp;Мітка:</translation>
    </message>
</context>
<context>
    <name>QP_UIProgress</name>
    <message>
        <source>Progress</source>
        <translation>Прогрес</translation>
    </message>
    <message>
        <source>Progress:</source>
        <translation>Прогрес:</translation>
    </message>
    <message>
        <source>&amp;OK</source>
        <translation>&amp;Так</translation>
    </message>
    <message>
        <source>Current operation:</source>
        <translation>Поточна операція:</translation>
    </message>
    <message>
        <source>Time Left:</source>
        <translation>Залишилося часу:</translation>
    </message>
</context>
<context>
    <name>QP_UIResize</name>
    <message>
        <source>Resize partition</source>
        <translation>Зміна розміру розділу</translation>
    </message>
    <message>
        <source>Minimum Size:</source>
        <translation>Мінімальний розмір:</translation>
    </message>
    <message>
        <source>Free Space &amp;Before:</source>
        <translation>Вільне місце на &amp;початку:</translation>
    </message>
    <message>
        <source>New Size:</source>
        <translation>Новий розмір:</translation>
    </message>
    <message>
        <source>Free Space &amp;After:</source>
        <translation>Вільне місце у &amp;кінці:</translation>
    </message>
    <message>
        <source>It is recommended to backup your data before do this operation!</source>
        <translation>Рекомендується створити резервну копію вашої інформації перед тим як зробити дану операцію!</translation>
    </message>
    <message>
        <source>&amp;OK</source>
        <translation>&amp;Так</translation>
    </message>
    <message>
        <source>&amp;Cancel</source>
        <translation>&amp;Ні</translation>
    </message>
</context>
<context>
    <name>QP_dlgAbout</name>
    <message>
        <source>&amp;OK</source>
        <translation>&amp;Так</translation>
    </message>
</context>
<context>
    <name>QP_dlgCreate</name>
    <message>
        <source>This filesystem cannot be greater of %1</source>
        <translation>Ця файлова система не може бути більшою ніж %1</translation>
    </message>
</context>
<context>
    <name>QP_dlgDevProperty</name>
    <message>
        <source>Devfs is enabled.</source>
        <translation>Включена підтрика devfs.</translation>
    </message>
    <message>
        <source>Devfs is disabled.</source>
        <translation>Відключена підтримка devfs.</translation>
    </message>
    <message>
        <source>Partition table: %1</source>
        <translation>Таблиця розділів: %1</translation>
    </message>
</context>
<context>
    <name>QP_dlgProgress</name>
    <message>
        <source>Initializing</source>
        <translation>Ініціялізація</translation>
    </message>
    <message>
        <source>Time Left: %1</source>
        <translation>Залишилось часу: %1</translation>
    </message>
    <message>
        <source>Operation: %1 of %2.
Current operation: %3</source>
        <translation>Операція: %1 из %2.
Поточна операція: %3</translation>
    </message>
    <message>
        <source>Operations completed sucessfully.</source>
        <translation>Операції завершені успішно.</translation>
    </message>
</context>
<context>
    <name>QP_dlgResize</name>
    <message>
        <source>Resize partition</source>
        <translation>Зміна розміру розділу</translation>
    </message>
    <message>
        <source>Minimum Size: %1 MB</source>
        <translation>Мінімальний розмір: %1 MB</translation>
    </message>
    <message>
        <source>Move partition</source>
        <translation>Пересунути розділ</translation>
    </message>
</context>
</TS>
